==> sdx-2.2.1-src.zip: sdx-2.2.1/src/java/fr/gouv/culture/sdx/pipeline/Pipeline.java <==
/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/

package fr.gouv.culture.sdx.pipeline;

import fr.gouv.culture.sdx.exception.SDXException;
import fr.gouv.culture.sdx.utils.constants.Node;
import org.apache.avalon.framework.component.Composable;
import org.apache.avalon.framework.configuration.Configurable;
import org.apache.avalon.framework.logger.LogEnabled;
import org.apache.avalon.framework.parameters.Parameters;
import org.apache.cocoon.xml.XMLPipe;

import java.io.File;
import java.util.Hashtable;

public interface Pipeline extends XMLPipe, LogEnabled, Configurable, Composable {

    /**String representation of the element name "pipeline". */
    public static final String ELEMENT_NAME = "pipeline";

    /**String representation of the element name "pipelines". */
    public static final String ELEMENT_NAME_PIPELINES = "pipelines";

    /**String representation of the "pipeline" attribute name "id" in our xconf config files. */
    public static final String ATTRIBUTE_ID = Node.Name.ID;

    /**String representation of the "pipeline" attribute name "type" in our xconf config files. */
    public static final String ATTRIBUTE_TYPE = Node.Name.TYPE;

    /**String representation of the pipeline package name (including trailing separator "."). */
    public static final String PACKAGE_QUALNAME = "fr.gouv.culture.sdx.pipeline.";

    /**String representation of the pipeline class name suffix. */
    public static final String CLASS_NAME_SUFFIX = "Pipeline";

    /**Generates a new instance of a Pipeline object*/
    public Pipeline newInstance() throws SDXException;

    /**Set's the default pipeline parameters
     *
     * @param params The parameters for steps of the pipeline
     */
    public void setParameters(Parameters params);

    /**Returns the id for the pipeline*/
    public String getId();

    /** The parameters for this pipeline. */
    public Parameters getParameters();

    /**Sets Properties.
     *
     * @param props A Properties object for configuration etc.
     */
    public void setProperties(Hashtable props);

    /**
     * Adds a transformation to the pipeline and sets the consumer of the last
     * transformation to be the newly added transformation.
     * @param t     The transformation to be added.
     */
    public void addTransformation(Transformation t) throws SDXException;

    /**Returns a byte array which contains the
     * data of a transformation step. The data will only be present
     * after a pipeline is executed, if no transformation data is retained
     * <code>null</code>  will be returned
     */
    public byte[] getTransformedBytes();

    /**Returns a file which contains the
     * data of a transformation step. The data will only be present
     * after a pipeline is executed, if no transformation data is retained
     * <code>null</code>  will be returned
     */
    public File getTransformedFile() throws SDXException;

}

==> sdx-2.3b1-src.zip: sdx-2.3b1/src/java/fr/gouv/culture/sdx/pipeline/Pipeline.java <==
/*
SDX: Documentary System in XML.
Copyright (C) 2000, 2001, 2002  Ministere de la culture et de la communication (France), AJLSM

Ministere de la culture et de la communication,
Mission de la recherche et de la technologie
3 rue de Valois, 75042 Paris Cedex 01 (France)
mrt@culture.fr, michel.bottin@culture.fr

AJLSM, 17, rue Vital Carles, 33000 Bordeaux (France)
sevigny@ajlsm.com

This program is free software; you can redistribute it and/or
modify it under the terms of the GNU General Public License
as published by the Free Software Foundation; either version 2
of the License, or (at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
See the GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with this program; if not, write to the
Free Software Foundation, Inc.
59 Temple Place - Suite 330, Boston, MA  02111-1307, USA
or connect to:
http://www.fsf.org/copyleft/gpl.html
*/

package fr.gouv.culture.sdx.pipeline;

import fr.gouv.culture.sdx.exception.SDXException;
import fr.gouv.culture.sdx.utils.SdxObject;
import org.apache.avalon.framework.parameters.Parameters;
import org.apache.cocoon.xml.XMLPipe;

import java.io.File;

public interface Pipeline extends XMLPipe, SdxObject {

    /**String representation of the pipeline package name (including trailing separator "."). */
    public static final String PACKAGE_QUALNAME = "fr.gouv.culture.sdx.pipeline.";

    /**String representation of the pipeline class name suffix. */
    public static final String CLASS_NAME_SUFFIX = "Pipeline";

    /**Generates a new instance of a Pipeline object*/
    public Pipeline newInstance() throws SDXException;

    /**Set's the default pipeline parameters
     *
     * @param params The parameters for steps of the pipeline
     */
    public void setParameters(Parameters params);


    /** The parameters for this pipeline. */
    public Parameters getParameters();

    /**
     * Adds a transformation to the pipeline and sets the consumer of the last
     * transformation to be the newly added transformation.
     * @param t     The transformation to be added.
     */
    public void addTransformation(Transformation t) throws SDXException;

    /**Returns a byte array which contains the
     * data of a transformation step. The data will only be present
     * after a pipeline is executed, if no transformation data is retained
     * <code>null</code>  will be returned
     */
    public byte[] getTransformedBytes();

    /**Returns a file which contains the
     * data of a transformation step. The data will only be present
     * after a pipeline is executed, if no transformation data is retained
     * <code>null</code>  will be returned
     */
    public File getTransformedFile() throws SDXException;

}
